16.118. cdist-type__pacman_conf(7) — cdist 6.9.8 documentation

# 16.118. cdist-type__pacman_conf(7)

## 16.118.1. NAME

cdist-type__pacman_conf - Manage pacman configuration

## 16.118.2. DESCRIPTION

The type allows you to configure options section, add or delete repositories and manage mirrorlists

## 16.118.3. REQUIRED PARAMETERS

section

  'options' for configure options section

  Otherwise it specifies a repository or a plain file

key

  Specifies the key which will be set

  If section = 'options' or file is not set the key will be checked against available keys from pacman.conf

value

  Specifies the value which will be set against the key

## 16.118.4. OPTIONAL PARAMETERS

state

  'present' or 'absent', defaults to 'present'

file

  Specifies the filename.

  The managed file will be named like 'plain_file_filename'

  If supplied the key will not be checked.

## 16.118.5. EXAMPLES

    # Manage options section in pacman.conf
    __pacman_conf options_Architecture --section options --key Architecture --value auto

    # Add new repository
    __pacman_conf localrepo_Server --section localrepo --key Server --value "file:///var/cache/pacman/pkg"

    # Add mirror to a mirrorlist
    __pacman_conf customlist_Server --file customlist --section customlist --key Server\
        --value "file:///var/cache/pacman/pkg"

## 16.118.6. SEE ALSO

grep(1)

## 16.118.7. AUTHORS

Dominique Roux <dominique.roux4@gmail.com>

## 16.118.8. COPYING

Copyright (C) 2015 Dominique Roux. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.